@@ -224,13 +224,13 @@ class Accounts(Resource):
             if super().get_bank_id() == super().COOP:
 
                 data["message"] = response_data.get("MessageDescription", "")
-                data["code"] = response_data.get("MessageCode", "-1111111")
+                data["code"] = response_data.get("MessageCode", "-111111")
                 data["balance"] = response_data.get("AvailableBalance", "")
 
             elif super().get_bank_id() == super().EQUITY:
 
                 data["message"] = response_data.get("message", "")
-                data["code"] = response_data.get("code", -1111111)
+                data["code"] = response_data.get("code", -111111)
                 if bool(response_data.get("data", {}).get("balances", [])):
                     data["balance"] = response_data.get("data", {}).get(
                         "balances", [])[0].get("amount", -1)
@@ -241,7 +241,7 @@ class Accounts(Resource):
 
                 data["message"] = ''
                 data["code"] = int(float(response_data.get("sendTransactionResponse", {}).get(
-                    "return", {}).get("C24TRANRES", {}).get("ACTION_CODE", "-1111111")))
+                    "return", {}).get("C24TRANRES", {}).get("ACTION_CODE", "-111111")))
                 data["balance"] = float(response_data.get("sendTransactionResponse", {}).get(
                     "return", {}).get("C24TRANRES", {}).get("AVAILABLE_BALANCE", -1))
                 if data["code"]:
@@ -254,7 +254,7 @@ class Accounts(Resource):
             if super().get_bank_id() == super().COOP:
 
                 data["message"] = response_data.get("MessageDescription", "")
-                data["code"] = response_data.get("MessageCode", "-1111111")
+                data["code"] = response_data.get("MessageCode", "-111111")
                 data["transactions"] = []
 
                 transactions = response_data.get("Transactions", [])
@@ -310,7 +310,7 @@ class Accounts(Resource):
             if super().get_bank_id() == super().COOP:
 
                 data["message"] = response_data.get("MessageDescription", "")
-                data["code"] = response_data.get("MessageCode", "-1111111")
+                data["code"] = response_data.get("MessageCode", "-111111")
                 data["account_name"] = ""
 
             elif super().get_bank_id() == super().EQUITY:
@@ -326,7 +326,7 @@ class Accounts(Resource):
             elif super().get_bank_id() == super().DTB:
                 if isinstance(response_data, list):
                     data["message"] = response_data[0]
-                    data["code"] = -1111111
+                    data["code"] = -111111
                     data["account_name"] = ""
                 else:
                     data["message"] = response_data.get(
@@ -340,7 +340,7 @@ class Accounts(Resource):
             if super().get_bank_id() == super().COOP:
 
                 data["message"] = response_data.get("MessageDescription", "")
-                data["code"] = response_data.get("MessageCode", "-1111111")
+                data["code"] = response_data.get("MessageCode", "-111111")
                 data["transactions"] = []
 
                 transactions = response_data.get("Transactions", [])
@@ -410,7 +410,7 @@ class Accounts(Resource):
 
                 data["message"] = ''
                 data["code"] = int(float(response_data.get("sendTransactionResponse", {}).get(
-                    "return", {}).get("C24TRANRES", {}).get("ACTION_CODE", "-1111111")))
+                    "return", {}).get("C24TRANRES", {}).get("ACTION_CODE", "-111111")))
                 if data["code"]:
                     data["message"] = "Transaction Failed"
                 else:
@@ -457,6 +457,11 @@ class Accounts(Resource):
                     data['response'] = response_data
 
         if bool(data):
+            
+            if 'transactions' in data.keys() and 'code' in data.keys():
+                if len(data["transactions"])==0 and int(data["code"])==-111111:
+                    data['error'] = response_data
+
             return data
         if super().get_bank_id() in super().THIRD_PARTY_BANKING.keys():
             return response_data
