@@ -2,6 +2,7 @@ from bank_sync.Resources.resource import Resource
 from bank_sync.Resources.accounts import Accounts
 from bank_sync.Resources.payments import Payments
 from bank_sync.models import IPN
+from django.core.exceptions import ObjectDoesNotExist
 try:
     from django.conf import settings
 except Exception as e:
@@ -36,12 +37,12 @@ class Bank(Resource):
         self._nash = nash
         super().__init__("BankAPI", self._nash.get_headers(), self._nash.get_params())
         super().set_bank_id(bank_id)
-        # We will set an IPN object that will be used by all banks resources
-        super().set_ipn_object(ipn_object=IPN.objects)
+
+        super().refresh_identity_token()
 
     def resource(self, resource_name):
         resource = self._resources[resource_name].set_bank_id(
-            super().get_bank_id()).set_headers(self._nash.get_headers()).set_ipn_object(ipn_object=super().get_ipn_object)
+            super().get_bank_id()).set_headers(self._nash.get_headers()).set_identity_token(identity_token=super().get_identity_token)
 
         return resource
 
@@ -88,43 +89,59 @@ class Bank(Resource):
         exec_global = self.exec_global_function(
             operation=operation, payload=payload)
         
-        if operation in [super().IPN_REGISTER]:
-            # get the response and change the url saved, which it the service url, with the user url
-            rsp=super().response()
-            rsp['url']=user_url
-            super().set_response(response=rsp)
+        try:
+            
+            if operation in [super().IPN_REGISTER]:
+                # get the response and change the url saved, which it the service url, with the user url
+                rsp=super().response()
+                rsp['url']=user_url
+                super().set_response(response=rsp)
 
-        # If the operation performed is to create an IPN
-        if operation == super().IPN_REGISTER:
-            # If succesfull Nash returns the generated client id and client secret
-            if 'client_id' in super().response().keys():
+            # If the operation performed is to create an IPN
+            if operation == super().IPN_REGISTER:
+                # If succesfull Nash returns the generated client id and client secret
+                if 'client_id' in super().response().keys():
 
-                super().get_ipn_object.create(bank_id=payload.get('bank_id', ''), client_id=super().response().get('client_id', ''), client_secret=super().response().get(
-                    'client_secret', ''), account_number=payload.get('account_number', ''), url=user_url)
+                    IPN.objects.create(bank_id=payload.get('bank_id', ''), client_id=super().response().get('client_id', ''), client_secret=super().response().get(
+                        'client_secret', ''), account_number=payload.get('account_number', ''), url=user_url)
 
-        # If the operation performed is to update an IPN
-        elif operation == super().IPN_GENERATE_CLIENT_SECRET:
-            # If succesfull Nash returns the client id
-            if 'client_id' in super().response().keys():
+            # If the operation performed is to update an IPN
+            elif operation == super().IPN_GET:
+                # If succesfull Nash returns the client id and account_number
+                if 'client_id' in super().response().keys() and 'account_number' in super().response().keys() :
 
-                data = super().get_ipn_object.filter(client_id=payload.get('client_id', ''),account_number=payload.get('account_number', ''))
+                    data = IPN.objects.get(client_id=super().response().get('client_id', ''),account_number=super().response().get('account_number', ''))
 
-                if bool(len(data)):
-                    data = data.first()
+                    # if bool(len(data)):
+                    #     data = data.first()
+
+                    rsp=super().response()
+                    rsp['url']=data.url
+                    super().set_response(response=rsp)
+
+            # If the operation performed is to update an IPN
+            elif operation == super().IPN_GENERATE_CLIENT_SECRET:
+                # If succesfull Nash returns the client id
+                if 'client_id' in super().response().keys():
+
+                    data = IPN.objects.get(client_id=payload.get('client_id', ''),account_number=payload.get('account_number', ''))
+
+                    # if bool(len(data)):
+                    #     data = data.first()
                     if 'client_secret' in super().response().keys():
-                       data.client_secret = super().response().get('client_secret', '')
+                        data.client_secret = super().response().get('client_secret', '')
 
                     data.save()
 
-        # If the operation performed is to update an IPN
-        elif operation == super().IPN_UPDATE:
-            # If succesfull Nash returns the client id
-            if 'client_id' in super().response().keys():
+            # If the operation performed is to update an IPN
+            elif operation == super().IPN_UPDATE:
+                # If succesfull Nash returns the client id
+                if 'client_id' in super().response().keys():
 
-                data = super().get_ipn_object.filter(client_id=payload.get('client_id', ''))
+                    data = IPN.objects.get(client_id=payload.get('client_id', ''))
 
-                if bool(len(data)):
-                    data = data.first()
+                    # if bool(len(data)):
+                    #     data = data.first()
                     if 'bank_id' in payload.keys():
                         data.bank_id = payload.get('bank_id')
                     if 'account_number' in payload.keys():
@@ -139,17 +156,20 @@ class Bank(Resource):
 
                     data.save()
 
-        # If the operation performed is to delete an IPN
-        elif operation == super().IPN_DELETE:
-            # If succesfull Nash returns the client id
-            if 'client_id' in super().response().keys():
+            # If the operation performed is to delete an IPN
+            elif operation == super().IPN_DELETE:
+                # If succesfull Nash returns the client id
+                if 'client_id' in super().response().keys():
 
-                data = super().get_ipn_object.filter(client_id=payload.get(
-                    'client_id', ''))
+                    data = IPN.objects.get(client_id=payload.get(
+                        'client_id', ''))
 
-                if bool(len(data)):
+                    # if bool(len(data)):
                     data.delete()
 
+        except ObjectDoesNotExist:
+            print("Either the blog or entry doesn't exist.")
+            
         return exec_global
 
     # This is a 'global' function
